/**
 * Represents a class compatible with our class conversion system.
 * E.g. PublicKey here satisfies 'IOClass'.
 * ```
 *    class PublicKey {
 *      toString() {
 *        return '...';
 *      }
 *      static fromString(str) {
 *        return new PublicKey(...);
 *      }
 *    }
 * ```
 */
interface IOClass {
    new (...args: any): any;
    /**
     * Creates an IOClass from a given string.
     */
    fromString?: (str: string) => any;
    /**
     * Creates an IOClass from a given JSON object.
     */
    fromJSON?: (obj: object) => any;
}
/**
 * Registered classes available for conversion.
 */
export interface ClassConverterInput {
    [className: string]: IOClass;
}
/**
 * Represents a class in a JSON-friendly encoding.
 */
export interface StringEncodedClass {
    /**
     * The class type.
     */
    type: string;
    /**
     * The class data string.
     */
    data: string;
}
/**
 * Represents a class in a JSON-friendly encoding.
 */
export interface JsonEncodedClass {
    /**
     * The class type.
     */
    type: string;
    /**
     * The class data string.
     */
    data: object;
}
/**
 * Whether a class is a complex object or simply represented by a string.
 */
export type ClassEncoding = 'string' | 'object';
/**
 * Handles mapping of classes to names, and calling toString and fromString to convert to and from JSON-friendly formats.
 * Takes a class map as input.
 */
export declare class ClassConverter {
    private toClass;
    private toName;
    /**
     * Create a class converter from a table of classes.
     * @param stringClassMap - The class table of string encoded classes.
     * @param objectClassMap - The class table of complex object classes
     */
    constructor(stringClassMap?: ClassConverterInput, objectClassMap?: ClassConverterInput);
    /**
     * Register a class with a certain name.
     * This name is used for conversion from and to this class.
     * @param type - The class name to use for serialization.
     * @param class_ - The class object.
     * @param encoding - Whether the class is a complex object or simply represented by a string.
     */
    register(type: string, class_: IOClass, encoding: ClassEncoding): void;
    /**
     * Does this type name have a registered class?
     * @param type - The type name.
     * @returns If there's a registered class.
     */
    isRegisteredClassName(type: string): boolean;
    /**
     * Is this class object registered?
     * @param obj - The class object.
     * @returns If it is a registered class.
     */
    isRegisteredClass(obj: any): boolean;
    /**
     * Convert a JSON-like object to a class object.
     * @param jsonObj - An object encoding a class.
     * @returns The class object.
     */
    toClassObj(jsonObj: JsonEncodedClass | StringEncodedClass): any;
    /**
     * Convert a class object to a JSON object.
     * @param classObj - A JSON encoding a class.
     * @returns The class object.
     */
    toJsonObj(classObj: any): JsonEncodedClass | StringEncodedClass;
}
export {};
//# sourceMappingURL=class_converter.d.ts.map